@@ -1,21 +1,34 @@
-# Copyright 2007 Gentoo Foundation
+# Copyright 2007-2014 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Id: __init__.py 15726 2010-03-02 22:55:54Z zmedico $
 
 from __future__ import print_function
 
 __all__ = ["SETPREFIX", "get_boolean", "SetConfigError",
 	"SetConfig", "load_default_config"]
 
+import io
+import logging
+import sys
 try:
-	from configparser import SafeConfigParser, NoOptionError
+	from configparser import NoOptionError, ParsingError
+	if sys.hexversion >= 0x3020000:
+		from configparser import ConfigParser as SafeConfigParser
+	else:
+		from configparser import SafeConfigParser
 except ImportError:
-	from ConfigParser import SafeConfigParser, NoOptionError
+	from ConfigParser import SafeConfigParser, NoOptionError, ParsingError
+import portage
 from portage import os
 from portage import load_mod
+from portage import _unicode_decode
+from portage import _unicode_encode
+from portage import _encodings
 from portage.const import USER_CONFIG_PATH, GLOBAL_CONFIG_PATH
+from portage.const import VCS_DIRS
+from portage.const import _ENABLE_SET_CONFIG
 from portage.exception import PackageSetNotFound
 from portage.localization import _
+from portage.util import writemsg_level
 
 SETPREFIX = "@"
 
@@ -36,26 +49,41 @@ class SetConfig(object):
 	def __init__(self, paths, settings, trees):
 		self._parser = SafeConfigParser(
 			defaults={
+				"EPREFIX" : settings["EPREFIX"],
+				"EROOT" : settings["EROOT"],
 				"PORTAGE_CONFIGROOT" : settings["PORTAGE_CONFIGROOT"],
 				"ROOT" : settings["ROOT"],
 			})
-		#self._parser.read(paths)
-		# The "paths" argument is ignored and the config for
-		# system and world sets is hardcoded below.
-		parser = self._parser
 
-		parser.add_section("world")
-		parser.set("world", "class", "portage._sets.base.DummyPackageSet")
-		parser.set("world", "world-candidate", "False")
-		parser.set("world", "packages", "@selected @system")
+		if _ENABLE_SET_CONFIG:
+			# use read_file/readfp in order to control decoding of unicode
+			try:
+				# Python >=3.2
+				read_file = self._parser.read_file
+			except AttributeError:
+				read_file = self._parser.readfp
 
-		parser.add_section("selected")
-		parser.set("selected", "class", "portage._sets.files.WorldSelectedSet")
-		parser.set("selected", "world-candidate", "False")
-
-		parser.add_section("system")
-		parser.set("system", "class", "portage._sets.profiles.PackagesSystemSet")
-		parser.set("system", "world-candidate", "False")
+			for p in paths:
+				f = None
+				try:
+					f = io.open(_unicode_encode(p,
+						encoding=_encodings['fs'], errors='strict'),
+						mode='r', encoding=_encodings['repo.content'],
+						errors='replace')
+				except EnvironmentError:
+					pass
+				else:
+					try:
+						read_file(f)
+					except ParsingError as e:
+						writemsg_level(_unicode_decode(
+							_("!!! Error while reading sets config file: %s\n")
+							) % e, level=logging.ERROR, noiselevel=-1)
+				finally:
+					if f is not None:
+						f.close()
+		else:
+			self._create_default_config()
 
 		self.errors = []
 		self.psets = {}
@@ -64,6 +92,80 @@ class SetConfig(object):
 		self._parsed = False
 		self.active = []
 
+	def _create_default_config(self):
+		"""
+		Create a default hardcoded set configuration for a portage version
+		that does not support set configuration files. This is only used
+		in the current branch of portage if _ENABLE_SET_CONFIG is False.
+		Even if it's not used in this branch, keep it here in order to
+		minimize the diff between branches.
+
+			[world]
+			class = portage.sets.base.DummyPackageSet
+			packages = @selected @system
+
+			[selected]
+			class = portage.sets.files.WorldSelectedSet
+
+			[system]
+			class = portage.sets.profiles.PackagesSystemSet
+
+		"""
+		parser = self._parser
+
+		parser.remove_section("world")
+		parser.add_section("world")
+		parser.set("world", "class", "portage.sets.base.DummyPackageSet")
+		parser.set("world", "packages", "@profile @selected @system")
+
+		parser.remove_section("selected")
+		parser.add_section("selected")
+		parser.set("selected", "class", "portage.sets.files.WorldSelectedSet")
+
+		parser.remove_section("selected-packages")
+		parser.add_section("selected-packages")
+		parser.set("selected-packages", "class", "portage.sets.files.WorldSelectedPackagesSet")
+
+		parser.remove_section("selected-sets")
+		parser.add_section("selected-sets")
+		parser.set("selected-sets", "class", "portage.sets.files.WorldSelectedSetsSet")
+
+		parser.remove_section("system")
+		parser.add_section("system")
+		parser.set("system", "class", "portage.sets.profiles.PackagesSystemSet")
+
+		parser.remove_section("security")
+		parser.add_section("security")
+		parser.set("security", "class", "portage.sets.security.NewAffectedSet")
+
+		parser.remove_section("usersets")
+		parser.add_section("usersets")
+		parser.set("usersets", "class", "portage.sets.files.StaticFileSet")
+		parser.set("usersets", "multiset", "true")
+		parser.set("usersets", "directory", "%(PORTAGE_CONFIGROOT)setc/portage/sets")
+		parser.set("usersets", "world-candidate", "true")
+
+		parser.remove_section("live-rebuild")
+		parser.add_section("live-rebuild")
+		parser.set("live-rebuild", "class", "portage.sets.dbapi.VariableSet")
+		parser.set("live-rebuild", "variable", "INHERITED")
+		parser.set("live-rebuild", "includes", " ".join(sorted(portage.const.LIVE_ECLASSES)))
+
+		parser.remove_section("module-rebuild")
+		parser.add_section("module-rebuild")
+		parser.set("module-rebuild", "class", "portage.sets.dbapi.OwnerSet")
+		parser.set("module-rebuild", "files", "/lib/modules")
+
+		parser.remove_section("preserved-rebuild")
+		parser.add_section("preserved-rebuild")
+		parser.set("preserved-rebuild", "class", "portage.sets.libs.PreservedLibraryConsumerSet")
+
+		parser.remove_section("x11-module-rebuild")
+		parser.add_section("x11-module-rebuild")
+		parser.set("x11-module-rebuild", "class", "portage.sets.dbapi.OwnerSet")
+		parser.set("x11-module-rebuild", "files", "/usr/lib/xorg/modules")
+		parser.set("x11-module-rebuild", "exclude-files", "/usr/bin/Xorg")
+
 	def update(self, setname, options):
 		parser = self._parser
 		self.errors = []
@@ -100,13 +202,18 @@ class SetConfig(object):
 				classname = "portage._sets.files.StaticFileSet"
 			else:
 				classname = parser.get(sname, "class")
-			
+
+			if classname.startswith('portage.sets.'):
+				# The module has been made private, but we still support
+				# the previous namespace for sets.conf entries.
+				classname = classname.replace('sets', '_sets', 1)
+
 			# try to import the specified class
 			try:
 				setclass = load_mod(classname)
 			except (ImportError, AttributeError):
 				try:
-					setclass = load_mod("portage._sets."+classname)
+					setclass = load_mod("portage._sets." + classname)
 				except (ImportError, AttributeError):
 					self.errors.append(_("Could not import '%(class)s' for section "
 						"'%(section)s'") % {"class": classname, "section": sname})
@@ -131,8 +238,8 @@ class SetConfig(object):
 							self.errors.append(_("Redefinition of set '%s' (sections: '%s', '%s')") % (x, self.psets[x].creator, sname))
 						newsets[x].creator = sname
 						if parser.has_option(sname, "world-candidate") and \
-							not parser.getboolean(sname, "world-candidate"):
-							newsets[x].world_candidate = False
+							parser.getboolean(sname, "world-candidate"):
+							newsets[x].world_candidate = True
 					self.psets.update(newsets)
 				else:
 					self.errors.append(_("Section '%(section)s' is configured as multiset, but '%(class)s' "
@@ -150,8 +257,8 @@ class SetConfig(object):
 						self.psets[setname] = setclass.singleBuilder(optdict, self.settings, self.trees)
 						self.psets[setname].creator = sname
 						if parser.has_option(sname, "world-candidate") and \
-							not parser.getboolean(sname, "world-candidate"):
-							self.psets[setname].world_candidate = False
+							parser.getboolean(sname, "world-candidate"):
+							self.psets[setname].world_candidate = True
 					except SetConfigError as e:
 						self.errors.append(_("Configuration error in section '%s': %s") % (sname, str(e)))
 						continue
@@ -175,7 +282,6 @@ class SetConfig(object):
 		except KeyError:
 			raise PackageSetNotFound(setname)
 		myatoms = myset.getAtoms()
-		parser = self._parser
 
 		if ignorelist is None:
 			ignorelist = set()
@@ -194,9 +300,30 @@ class SetConfig(object):
 		return myatoms
 
 def load_default_config(settings, trees):
-	setconfigpaths = [os.path.join(GLOBAL_CONFIG_PATH, "sets.conf")]
-	setconfigpaths.append(os.path.join(settings["PORTDIR"], "sets.conf"))
-	setconfigpaths += [os.path.join(x, "sets.conf") for x in settings["PORTDIR_OVERLAY"].split()]
-	setconfigpaths.append(os.path.join(settings["PORTAGE_CONFIGROOT"],
-		USER_CONFIG_PATH, "sets.conf"))
-	return SetConfig(setconfigpaths, settings, trees)
+
+	if not _ENABLE_SET_CONFIG:
+		return SetConfig(None, settings, trees)
+
+	global_config_path = GLOBAL_CONFIG_PATH
+	if portage.const.EPREFIX:
+		global_config_path = os.path.join(portage.const.EPREFIX,
+			GLOBAL_CONFIG_PATH.lstrip(os.sep))
+	vcs_dirs = [_unicode_encode(x, encoding=_encodings['fs']) for x in VCS_DIRS]
+	def _getfiles():
+		for path, dirs, files in os.walk(os.path.join(global_config_path, "sets")):
+			for d in dirs:
+				if d in vcs_dirs or d.startswith(b".") or d.endswith(b"~"):
+					dirs.remove(d)
+			for f in files:
+				if not f.startswith(b".") and not f.endswith(b"~"):
+					yield os.path.join(path, f)
+
+		dbapi = trees["porttree"].dbapi
+		for repo in dbapi.getRepositories():
+			path = dbapi.getRepositoryPath(repo)
+			yield os.path.join(path, "sets.conf")
+
+		yield os.path.join(settings["PORTAGE_CONFIGROOT"],
+			USER_CONFIG_PATH, "sets.conf")
+
+	return SetConfig(_getfiles(), settings, trees)
